==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
export let Stacked100BarSeries = /*@__PURE__*/ (() => {
    class Stacked100BarSeries extends StackedBarSeries {
        constructor() {
            super();
            this.ab = Stacked100BarSeries.$;
        }
        get_tx() {
            return true;
        }
        gz() {
            if (!isNaN_(this.gy)) {
                return super.gz();
            }
            return Defaults.h;
        }
        ac() {
            super.ac();
            this.mn(false);
        }
        by() {
            return new Stacked100BarSeriesView(this);
        }
        l4(a) {
            super.l4(a);
            this.u1 = a;
        }
        tp() {
            return this.u1;
        }
        ud() {
            super.ud();
            Stacked100DataPreparer.a(this);
        }
        get useHighMarkerFidelity() {
            return this.ss;
        }
    }
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
})();
/**
 * @hidden
 */
export let Stacked100BarSeriesView = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesView extends StackedBarSeriesView {
        constructor(a) {
            super(a);
            this.c6 = null;
            this.c6 = a;
        }
        cs() {
            return new Stacked100BarBucketCalculator(this);
        }
        as() {
            super.as();
            if (!this.q) {
                this.c0.ql = Defaults.c;
                this.c0.g4 = Defaults.i;
            }
        }
    }
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
export let Stacked100BarSeries = /*@__PURE__*/ (() => {
    class Stacked100BarSeries extends StackedBarSeries {
        constructor() {
            super();
            this.ab = Stacked100BarSeries.$;
        }
        get_xn() {
            return true;
        }
        ip() {
            if (!isNaN_(this.io)) {
                return super.ip();
            }
            return Defaults.h;
        }
        ac() {
            super.ac();
            this.pp(false);
        }
        cg() {
            return new Stacked100BarSeriesView(this);
        }
        o0(a) {
            super.o0(a);
            this.yr = a;
        }
        xf() {
            return this.yr;
        }
        x3() {
            super.x3();
            Stacked100DataPreparer.a(this);
        }
        get useHighMarkerFidelity() {
            return this.wi;
        }
    }
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
})();
/**
 * @hidden
 */
export let Stacked100BarSeriesView = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesView extends StackedBarSeriesView {
        constructor(a) {
            super(a);
            this.c9 = null;
            this.c9 = a;
        }
        cv() {
            return new Stacked100BarBucketCalculator(this);
        }
        au() {
            super.au();
            if (!this.q) {
                this.c3.ua = Defaults.c;
                this.c3.iu = Defaults.i;
            }
        }
    }
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
})();
